<?php

/*
Plugin Name: Tidi Notification Manager
Plugin URI: https://www.tidiweb.com/plugins/tidi-notification-manager
Description: Semplice plugin che gestisce l'attivazione e disattivazione delle notifiche email di sistema di WordPress.
Version: 1.0
Author: Tidiweb Solutions
Author URI: https://www.tidiweb.com
License: GPLv2 or later
License URI: https://www.gnu.org/licenses/gpl-2.0.html
Text Domain: tidi-notification-manager
Domain Path: /languages
*/


// Evita accessi diretti al file.
if (!defined('ABSPATH')) {
    exit;
}

/*  
    * WordPress preferisce una funzione globale come callback per register_setting(), 
    * invece di un metodo dentro una classe.
    * Filtra i dati e mantiene solo le chiavi previste.
    * Assicura che ogni valore sia true/false (booleano) per evitare iniezioni di codice.
*/
function tidi_nm_sanitize_options($input) {
    $sanitized_input = [];

    // Definizione delle chiavi consentite
    $allowed_keys = [
        'core_updates',
        'plugin_updates',
        'theme_updates',
        'password_reset_request',
        'password_changed',
        'new_user_registration'
    ];

    if (is_array($input)) {
        foreach ($allowed_keys as $key) {
            // Controlliamo se l'opzione è impostata e la convertiamo in booleano
            $sanitized_input[$key] = isset($input[$key]) ? filter_var($input[$key], FILTER_VALIDATE_BOOLEAN) : false;
        }
    }

    return $sanitized_input;
}

class tidi_notification_manager {

    private $options;

    public function __construct() {
        add_action('plugins_loaded', [$this, 'tidi_nm_load_textdomain']);
        add_action('admin_menu', [$this, 'add_admin_menu']);
        add_action('admin_init', [$this, 'register_settings']);
        add_action('admin_enqueue_scripts', [$this, 'enqueue_scripts']);
        $this->apply_notification_filters();
    }

    // Carico il textdomain per le traduzioni
    public function tidi_nm_load_textdomain() {
        load_plugin_textdomain('tidi-notification-manager', false, dirname(plugin_basename(__FILE__)) . '/languages/');
    }

    // Aggiungo il tab nel menù admin
    public function add_admin_menu() {
        add_menu_page(
            'Tidi Notification Manager',
            'Tidi Notification Manager',
            'manage_options',
            'tidi-notification-manager',
            [$this, 'settings_page'],
            'dashicons-email-alt',
            100
        );
    }


    // Salvataggio della configurazione
    public function register_settings() {
        register_setting(
            'tidi_notification_manager', 
            'tidi_notification_manager_options', 
            'tidi_nm_sanitize_options' // Passiamo una funzione globale e non un array dinamico
        );

        add_settings_section(
            'tidi_notification_manager_section',
            __('Gestione Notifiche Email','tidi-notification-manager'),
            null,
            'tidi-notification-manager'
        );

        $notifications = [
            'core_updates' => __('Notifica aggiornamenti automatici del core','tidi-notification-manager'),
            'plugin_updates' => __('Notifica aggiornamenti automatici dei plugin','tidi-notification-manager'),
            'theme_updates' => __('Notifica aggiornamenti automatici dei temi','tidi-notification-manager'),
            'password_reset_request' => __('Notifica richiesta cambio password','tidi-notification-manager'),
            'password_changed' => __('Notifica cambio password utente','tidi-notification-manager'),
            'new_user_registration' => __('Notifica registrazione nuovo utente','tidi-notification-manager'),
        ];

        foreach ($notifications as $key => $label) {
            add_settings_field(
                $key,
                $label,
                [$this, 'render_toggle_switch'],
                'tidi-notification-manager',
                'tidi_notification_manager_section',
                ['key' => $key]
            );
        }
    }

    // Visualizzazione dei checkbox
    public function render_toggle_switch($args) {
        $key = $args['key'];
        $options = get_option('tidi_notification_manager_options');
        $checked = isset($options[$key]) ? $options[$key] : false;
        echo '<label class="tidi-nm-switch">
                <input type="checkbox" class="tidi-nm-toggle" name="tidi_notification_manager_options[' . esc_attr($key) . ']" value="1" ' . checked(1, $checked, false) . ' />
                <span class="tidi-nm-slider" data-on="ON" data-off="OFF">' . ($checked ? 'ON' : 'OFF') . '</span>
              </label>';
    }

    // Carico gli script js e css del plugin
    public function enqueue_scripts() {
        wp_enqueue_style('tidi-nm-style', plugin_dir_url(__FILE__) . 'tidi-nm-style.css', [], '1.0');
        wp_enqueue_script('tidi-nm-script', plugin_dir_url(__FILE__) . 'tidi-nm-script.js', ['jquery'], '1.0', true);
    }

    // Contenuto della main page del plugin
    public function settings_page() {
        echo '<div class="tidi-nm-wrap">';
            echo '<div class="tidi-nm-header">';
                echo '<h1>Tidi Notification Manager</h1>';
                echo '<small>by <a target="_blank" href="https://www.tidiweb.com">Tidiweb Solutions</a></small><br>';
            echo '</div>';
            echo '<form method="post" action="options.php">';
                settings_fields('tidi_notification_manager');
                do_settings_sections('tidi-notification-manager');
                submit_button();
            echo '</form>';
        echo '</div>';
    }

    private function apply_notification_filters() {
        $options = get_option('tidi_notification_manager_options');

        if (isset($options['core_updates']) && !$options['core_updates']) {
            add_filter('auto_core_update_send_email', '__return_false');
        }

        if (isset($options['plugin_updates']) && !$options['plugin_updates']) {
            add_filter('auto_plugin_update_send_email', '__return_false');
        }

        if (isset($options['theme_updates']) && !$options['theme_updates']) {
            add_filter('auto_theme_update_send_email', '__return_false');
        }

        if (isset($options['password_reset_request']) && !$options['password_reset_request']) {
            add_filter('send_password_change_email', '__return_false');
        }

        if (isset($options['password_changed']) && !$options['password_changed']) {
            add_filter('send_email_change_email', '__return_false');
        }

        if (isset($options['new_user_registration']) && !$options['new_user_registration']) {
            add_filter('wp_new_user_notification_email', '__return_false');
        }
    }
}

new tidi_notification_manager();

// JavaScript File: tidi-nm-script.js
// CSS File: tidi-nm-style.css
?>
